@@ -549,7 +549,7 @@ class DataTransform(forms.ModelForm):
         #     DataTransformerTypes.objects.all().values_list('type', 'type'))
         # self.fields['type'] = ChoiceField(choices=tuple(types))
         try:
-            if hasattr(self.instance, 'get_children') and self.instance.get_children().count() >= 0:
+            if self.instance.get_children().count() >= 0:
                 print('Adding to child form node: ' + str(self.instance.get_children().count() + 1))
 
                 dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
@@ -578,6 +578,15 @@ class DataTransform(forms.ModelForm):
 
         except Exception as e:
             print(str(e))
+            dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,
+                                                                 fk_name='parent', form=DataTransform,
+                                                                 extra=0
+                                                                 )
+            self.nested_data_transformer_form = dataTransformerInlineFormset(
+                instance=self.instance,
+                data=self.data if self.is_bound else None,
+                files=self.files if self.is_bound else None
+            )
 
         self.nested_constants_form = DataConstantsTransformerInlineFormset(
             instance=self.instance,
