@@ -382,7 +382,7 @@ class DataTransformerConstants(models.Model):
 
 class HardwareDataTransformer(models.Model):
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
-    hardware = models.ManyToManyField(Channel,blank=True,null=False)
+    hardware = models.ManyToManyField(Channel,blank=True)
     data_transformer = models.ForeignKey(DataTransformer, on_delete=models.CASCADE, blank=True, null=True)
     index = models.IntegerField(blank=True, null=True, default=None)
     updated_at = models.DateTimeField(blank=True,auto_now=True)
